@@ -4,14 +4,23 @@ from contextlib import contextmanager
 from functools import wraps
 
 
+class Potency:
+    def __init__(self):
+        self.start = time.process_time()
+        self.end = self.start
+
+    def record(self):
+        last = self.start
+
+        self.end = time.process_time()
+        self.start = self.end
+
+        return self.end - last
+
+
 @contextmanager
-def timeblock(label):
-    start = time.process_time()
-    try:
-        yield
-    finally:
-        end = time.process_time()
-        print(f'{label} : {(end - start):.2f}')
+def timeblock():
+    yield Potency()
 
 
 def timefunc(func):
